==> v0.4.9.tar.gz: tsacdop-podcast-app-android/CHANGELOG.md <==
# Tsacdop Changelog

## v0.4.9

Release date 2020/8/1

### New features

* Player ui redesign.
* Added player height setting.
* Added skip slience feature.

### Bugs fixed

* Language fixs. (Thanks to Atrate)
* Make app movable to SD card. (Thanks to Atrate)

### Minor change

* Episode page open animation improved.
* POdcast page load faster than before.
* Removed unnecessary scroll overlay effect.
* Episode page bottom menu hide when scroll down. 

## v0.4.8

Release date 2020/7/25

### New features

* Filter in podcast detail page, you can also hide listened episodes.
* Search result ui improved, you can see more info for result.
* Update audio service to latest version.
* Support fast forward seconds and rewind seconds customize.
* Add Franch language support(beta).
* Add translators in about page.

### Bugs fixed

* Icon issue on below android 8 devices.

### Minor change

* Download button ui improved.
* Title changed to scrollable in episode detail page.
* Real dark theme improved.
* Add dot indicator in popup menu.
* Tap logo in homepage to toggle theme.

## v0.4.7

Release date 2020/7/18

### Bugs fixed

* Ompl files form other platform import error.
* Audio cache did't work.

## v0.4.6

Release date 2020/7/17

### Bugs fixed

* Mark listened not work.
* Recover subscribe wrong group.

## v0.4.5

Release date 2020/7/16

## New features

* OMPL backup file supports group.
* Add settings backup and restore.
* Enable R8 and dart obfuscate.

## Bugs fixed

* OMPL import not shown in group.

## Minor UI change

* Tap logo in homepage to toggle theme mode.
* Change subscribe button style.
* Improve history chart style.

## v0.4.0

Release date 2020/7/9

### New features

* Localization, changed all UI strings in app to support locale, support languages include en & zh right now.
* Changed episode popup menu UI, add a switch to tap to open popup men.

### Minor UI change

* Improve dropdown menu UI.
* Change icons color in setting page.
* Improve player panel animation.
* Add scroll bar in libraries page.

## v0.3.6

Release date 2020/6/30

### New feature

* Add sleep timer settings. include default time, auto start sleep timer, etc.

### Bug fixed

* Crash on stop player.
* Some download file didn't auto deleted.

## v0.3.5

Release date 2020/6/20
This is a energency release.

### Bugs fixed

* Crashed in download page or button after remove a podcast. Add episode check when load tasks from flutterdownloader.

### Minor UI change

* Add buy me a coffee in about page.
* Remove progress number in download list in failed task, change refresh icon color to red.

## v0.3.4

Release date 2020/6/16

### New Feature

* Support auto download new episodes, you can choose which podcast you want to auto download, you can also set if download using cellular data.
* Support auto delete downloaded episode, you can set days before delete.
* Support customize episode popup menu, you can add options you most want, **Like** | **Mark Listened** | **Download** newly added.
* Improved downloaded file manager, you can now sort downloads by date or size, you can also only view listened downloads.

### Minor UI Change

* Removed the listened indicator, increased the color difference for listened episodes.
* Add text in podcast manage page menu.
* Change episode shownote font to Martel.

### Bugs Fixed

* Auto play when receive notification.
* Lose podcast when import OMPL file.

### Other

* Add privacy policy.

==> v0.4.12.tar.gz: tsacdop-podcast-app-android/CHANGELOG.md <==
# Tsacdop Changelog

## 0.4.12

Release date 2020/8/15

### Bugs fixed

* Crash when reorder episodes or podcasts.
* Popup menu setting import bug.
* Default language failed to load.

### Minor changes

* Change language|feedback|podcast settings to button sheet.
* Add history in home playlist button.
* History page UI improved.

## 0.4.11

Release date 2020/8/12

### New features

* Boost volume. You can change boost level in settings.
* You can tap time stamp to skip instantly in shownote when the episode is playing.
* Add history list in playlist page.
* You can also mark not listened now.

### Minor change

* Improved time picker UI.
* Add episode setting page.

### Bugs fix

* Play record didn't saved after stop playing.
* Network error message didn't disapear after skip to next.
* Fireside avatar load error.

## 0.4.10

Release date 2020/8/6

### Bugs fixed

* Episdoe date parse error.
* Play from start after interrupt.
* Playlist in player unstable.
* Language setting not saved after restart app.

### Minor change

* Fast forward and rewind buttons UI changed.

## v0.4.9

Release date 2020/8/1

### New features

* Player UI redesign.
* Added player height setting.
* Added skip silence feature.

### Bugs fixed

* Language fixs. (Thanks to Atrate)
* Make app movable to SD card. (Thanks to Atrate)

### Minor change

* Episode page open animation improved.
* Podcast page load faster than before.
* Removed unnecessary scroll overlay effect.
* Episode page bottom menu hide when scroll down. 

## v0.4.8

Release date 2020/7/25

### New features

* Filter in podcast detail page, you can also hide listened episodes.
* Search result ui improved, you can see more info for result.
* Update audio service to latest version.
* Support fast forward seconds and rewind seconds customize.
* Add Franch language support(beta).
* Add translators in about page.

### Bugs fixed

* Icon issue on below android 8 devices.

### Minor change

* Download button ui improved.
* Title changed to scrollable in episode detail page.
* Real dark theme improved.
* Add dot indicator in popup menu.
* Tap logo in homepage to toggle theme.

## v0.4.7

Release date 2020/7/18

### Bugs fixed

* Ompl files form other platform import error.
* Audio cache did't work.

## v0.4.6

Release date 2020/7/17

### Bugs fixed

* Mark listened not work.
* Recover subscribe wrong group.

## v0.4.5

Release date 2020/7/16

## New features

* OMPL backup file supports group.
* Add settings backup and restore.
* Enable R8 and dart obfuscate.

## Bugs fixed

* OMPL import not shown in group.

## Minor UI change

* Tap logo in homepage to toggle theme mode.
* Change subscribe button style.
* Improve history chart style.

## v0.4.0

Release date 2020/7/9

### New features

* Localization, changed all UI strings in app to support locale, support languages include en & zh right now.
* Changed episode popup menu UI, add a switch to tap to open popup men.

### Minor UI change

* Improve dropdown menu UI.
* Change icons color in setting page.
* Improve player panel animation.
* Add scroll bar in libraries page.

## v0.3.6

Release date 2020/6/30

### New feature

* Add sleep timer settings. include default time, auto start sleep timer, etc.

### Bug fixed

* Crash on stop player.
* Some download file didn't auto deleted.

## v0.3.5

Release date 2020/6/20
This is a energency release.

### Bugs fixed

* Crashed in download page or button after remove a podcast. Add episode check when load tasks from flutterdownloader.

### Minor UI change

* Add buy me a coffee in about page.
* Remove progress number in download list in failed task, change refresh icon color to red.

## v0.3.4

Release date 2020/6/16

### New Feature

* Support auto download new episodes, you can choose which podcast you want to auto download, you can also set if download using cellular data.
* Support auto delete downloaded episode, you can set days before delete.
* Support customize episode popup menu, you can add options you most want, **Like** | **Mark Listened** | **Download** newly added.
* Improved downloaded file manager, you can now sort downloads by date or size, you can also only view listened downloads.

### Minor UI Change

* Removed the listened indicator, increased the color difference for listened episodes.
* Add text in podcast manage page menu.
* Change episode shownote font to Martel.

### Bugs Fixed

* Auto play when receive notification.
* Lose podcast when import OMPL file.

### Other

* Add privacy policy.
